==> cdk8s-operator-0.0.52.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.52](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.50...v0.0.52) (2021-01-13)

### [0.0.51](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.50...v0.0.51) (2021-01-12)

### [0.0.50](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.48...v0.0.50) (2021-01-11)

### [0.0.49](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.48...v0.0.49) (2021-01-08)

### [0.0.48](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.47...v0.0.48) (2021-01-07)

### [0.0.47](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.46...v0.0.47) (2021-01-06)

### [0.0.46](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.45...v0.0.46) (2021-01-06)

### [0.0.45](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.44...v0.0.45) (2021-01-05)

### [0.0.44](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.43...v0.0.44) (2021-01-05)

### [0.0.43](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.42...v0.0.43) (2021-01-04)

### [0.0.42](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.41...v0.0.42) (2021-01-04)

### [0.0.41](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.40...v0.0.41) (2021-01-02)

### [0.0.40](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.39...v0.0.40) (2021-01-01)

### [0.0.39](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.38...v0.0.39) (2021-01-01)

### [0.0.38](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.37...v0.0.38) (2020-12-31)

### [0.0.37](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.36...v0.0.37) (2020-12-30)

### [0.0.36](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.35...v0.0.36) (2020-12-30)

### [0.0.35](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.33...v0.0.35) (2020-12-29)

### [0.0.34](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.33...v0.0.34) (2020-12-29)

### [0.0.33](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.32...v0.0.33) (2020-12-28)

### [0.0.32](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.31...v0.0.32) (2020-12-28)

### [0.0.31](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.30...v0.0.31) (2020-12-26)

### 0.0.30 (2020-12-24)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.29 (2020-12-24)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.28 (2020-12-23)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.27 (2020-12-22)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.26 (2020-12-22)

### 0.0.25 (2020-12-21)

### 0.0.24 (2020-12-20)

### 0.0.23 (2020-12-18)

### 0.0.22 (2020-12-18)

### 0.0.21 (2020-12-17)

### 0.0.20 (2020-12-17)

### 0.0.19 (2020-12-16)

### 0.0.18 (2020-12-15)

### 0.0.17 (2020-12-15)

### 0.0.16 (2020-12-14)

### 0.0.15 (2020-12-12)

### 0.0.14 (2020-12-11)

### 0.0.13 (2020-12-09)

### 0.0.12 (2020-12-09)

### 0.0.11 (2020-12-08)

### 0.0.10 (2020-12-07)

### 0.0.9 (2020-12-07)

### 0.0.8 (2020-12-06)

### 0.0.7 (2020-12-06)

### 0.0.6 (2020-12-03)

### 0.0.5 (2020-12-02)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.4 (2020-12-02)

### 0.0.3 (2020-12-02)

### 0.0.2 (2020-12-02)

### 0.0.1 (2020-09-02)

==> cdk8s-operator-0.0.54.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.54](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.52...v0.0.54) (2021-01-15)

### [0.0.53](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.52...v0.0.53) (2021-01-14)

### [0.0.52](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.50...v0.0.52) (2021-01-13)

### [0.0.51](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.50...v0.0.51) (2021-01-12)

### [0.0.50](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.48...v0.0.50) (2021-01-11)

### [0.0.49](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.48...v0.0.49) (2021-01-08)

### [0.0.48](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.47...v0.0.48) (2021-01-07)

### [0.0.47](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.46...v0.0.47) (2021-01-06)

### [0.0.46](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.45...v0.0.46) (2021-01-06)

### [0.0.45](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.44...v0.0.45) (2021-01-05)

### [0.0.44](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.43...v0.0.44) (2021-01-05)

### [0.0.43](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.42...v0.0.43) (2021-01-04)

### [0.0.42](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.41...v0.0.42) (2021-01-04)

### [0.0.41](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.40...v0.0.41) (2021-01-02)

### [0.0.40](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.39...v0.0.40) (2021-01-01)

### [0.0.39](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.38...v0.0.39) (2021-01-01)

### [0.0.38](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.37...v0.0.38) (2020-12-31)

### [0.0.37](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.36...v0.0.37) (2020-12-30)

### [0.0.36](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.35...v0.0.36) (2020-12-30)

### [0.0.35](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.33...v0.0.35) (2020-12-29)

### [0.0.34](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.33...v0.0.34) (2020-12-29)

### [0.0.33](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.32...v0.0.33) (2020-12-28)

### [0.0.32](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.31...v0.0.32) (2020-12-28)

### [0.0.31](https://github.com/eladb/cdk8s-pack-prototype/compare/v0.0.30...v0.0.31) (2020-12-26)

### 0.0.30 (2020-12-24)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.29 (2020-12-24)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.28 (2020-12-23)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.27 (2020-12-22)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.26 (2020-12-22)

### 0.0.25 (2020-12-21)

### 0.0.24 (2020-12-20)

### 0.0.23 (2020-12-18)

### 0.0.22 (2020-12-18)

### 0.0.21 (2020-12-17)

### 0.0.20 (2020-12-17)

### 0.0.19 (2020-12-16)

### 0.0.18 (2020-12-15)

### 0.0.17 (2020-12-15)

### 0.0.16 (2020-12-14)

### 0.0.15 (2020-12-12)

### 0.0.14 (2020-12-11)

### 0.0.13 (2020-12-09)

### 0.0.12 (2020-12-09)

### 0.0.11 (2020-12-08)

### 0.0.10 (2020-12-07)

### 0.0.9 (2020-12-07)

### 0.0.8 (2020-12-06)

### 0.0.7 (2020-12-06)

### 0.0.6 (2020-12-03)

### 0.0.5 (2020-12-02)


### Bug Fixes

* make cdk8s-server executable ([5f12830](https://github.com/eladb/cdk8s-pack-prototype/commit/5f12830d6312a794007a2a1e5dd7e1f1aa5e9247))

### 0.0.4 (2020-12-02)

### 0.0.3 (2020-12-02)

### 0.0.2 (2020-12-02)

### 0.0.1 (2020-09-02)
